OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer matchade via telefonnummer integration via Talk i mobilen",
    "Local" : "Lokal",
    "Only visible to people on this instance and guests" : "Endast synlig för personer på denna instansen och gäster",
    "Federated" : "Federerad",
    "Only synchronize to trusted servers" : "Synkronisera endast med betrodda servrar",
    "Published" : "Publicerad",
    "Synchronize to trusted servers and the global and public address book" : "Synkronisera med betrodda servrar och den globala och offentliga adressboken",
    "Verify" : "Verifiera",
    "Verifying …" : "Verifierar ...",
    "Unable to change password" : "Kunde inte ändra lösenord",
    "Very weak password" : "Väldigt svagt lösenord",
    "Weak password" : "Svagt lösenord",
    "So-so password" : "Okej lösenord",
    "Good password" : "Bra lösenord",
    "Strong password" : "Starkt lösenord",
    "Groups" : "Grupper",
    "Group list is empty" : "Grupplistan är tom",
    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
    "{actor} added you to group {group}" : "{actor} adderade dig till gruppen {group}",
    "You added {user} to group {group}" : "Du adderade {user} till gruppen {group}",
    "{actor} added {user} to group {group}" : "{actor} adderade {user} till gruppen {group}",
    "An administrator added you to group {group}" : "En administratör adderade dig till gruppen {group}",
    "An administrator added {user} to group {group}" : "En administratör adderade {user} till gruppen {group}",
    "{actor} removed you from group {group}" : "{actor} tog bort dig från gruppen {group}",
    "You removed {user} from group {group}" : "Du tog bort {user} från gruppen {group}",
    "{actor} removed {user} from group {group}" : "{actor} tog bort {user} från gruppen {group}",
    "An administrator removed you from group {group}" : "En administratör tog bort dig från gruppen {group}",
    "An administrator removed {user} from group {group}" : "En administratör tog bort {user} från gruppen {group}",
    "Your <strong>group memberships</strong> were modified" : "Dina <strong>gruppmedlemskaper</strong> har ändrats",
    "{actor} changed your password" : "{actor} ändrade ditt lösenord",
    "You changed your password" : "Du ändrade ditt lösenord",
    "Your password was reset by an administrator" : "Ditt lösenord återställdes av en administratör",
    "Your password was reset" : "Ditt lösenord återställdes",
    "{actor} changed your email address" : "{actor} ändrade din e-postadress",
    "You changed your email address" : "Du ändrade din e-postadress",
    "Your email address was changed by an administrator" : "Din e-postadress ändrades av en administratör",
    "You created an app password for a session named \"{token}\"" : "Du skapade ett applösenord för en session med namnet \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "En administratör skapade ett applösenord för en session med namnet \"{token}\"",
    "You deleted app password \"{token}\"" : "Du tog bort applösenordet \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Du ändrade namn på applösenord \"{token}\" till \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Du tilldelade filsystem-åtkomst till applösenord \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Du återkallade filsystem-åtkomst från applösenord \"{token}\"",
    "Security" : "Säkerhet",
    "You successfully logged in using two-factor authentication (%1$s)" : "Du loggade in med tvåfaktorautentisering (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ett inloggningsförsök med tvåfaktorautentisering misslyckades (%1$s)",
    "Remote wipe was started on %1$s" : "Fjärrensning startades på %1$s",
    "Remote wipe has finished on %1$s" : "Fjärrensning slutfördes på %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ditt <strong>lösenord</strong> eller <strong>e-postadress</strong> har ändrats",
    "Apps" : "Appar",
    "Could not remove app." : "Kunde inte ta bort app.",
    "Could not update app." : "Kunde inte uppdatera app.",
    "Wrong password" : "Fel lösenord",
    "Unable to change personal password" : "Kunde inte byta personligt lösenord",
    "Saved" : "Sparad",
    "No user supplied" : "Ingen användare angiven",
    "Unable to change password. Password too long." : "Kunde inte byta lösenord. Lösenord för långt.",
    "Authentication error" : "Fel vid autentisering",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Vänligen ange ett administratörs återställningslösenord; annars kommer alla användardata att försvinna.",
    "Wrong admin recovery password. Please check the password and try again." : "Felaktigt återställningslösenord för administratör. Kontrollera lösenordet och prova igen.",
    "Backend does not support password change, but the user's encryption key was updated." : "Backend stödjer inte att lösenord ändras, men användarens krypteringsnyckel uppdaterades.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installera och uppdatera appar via appbutiken eller federerad molndelning",
    "Federated Cloud Sharing" : "Federerad Moln-delning",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL använder en föråldrad %1$s version (%2$s). Uppdatera ditt operativsystem annars kommer inte funktioner som %3$s fungera pålitligt.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Kunde inte bestämma om TLS-versionen av cURL är för gammal eller inte för ett fel uppstod under HTTPS-förfrågan mot https://nextcloud.com. Vänligen kontrollera Nextcloud loggfilen för fler detaljer.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache-modulen är inte laddad. För bättre prestanda rekommenderas det att ladda den i din PHP-installation.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache är inaktiverat. För bättre prestanda rekommenderas att lägga till <code>opcache.enable=1</code> i din PHP-konfiguration.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache är konfigurerad för att ta bort kodkommentarer. Med OPcache aktiverat måste <code>opcache.save_comments=1</code> sättas för att Nextcloud ska fungera.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud får inte använda OPcache API. Med OPcache aktiverat rekommenderas det starkt att inkludera alla Nextcloud-kataloger med <code>opcache.restrict_api</code> eller avaktivera denna inställning för att inaktivera OPcache API-begränsningar, för att förhindra fel under Nextcloud kärna eller appuppgraderingar.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud får inte använda OPcache API. Det rekommenderas starkt att inkludera alla Nextcloud-kataloger med <code>opcache.restrict_api</code> eller avaktivera denna inställning för att inaktivera OPcache API-begränsningar, för att förhindra fel under Nextcloud core eller appuppgraderingar.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "OPcache, som använder delat minne, är avaktiverat. För bättre prestanda rekommenderas att konfigurera <code>opcache.file_cache_only=0</code> i din PHP-konfiguration och att bara använda fil-cache som andrahands cache.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Det maximala antalet OPcache-nycklar har nästan överskridits. För att säkerställa att alla skript kan behållas i cachen, rekommenderas det att tillämpa <code>opcache.max_accelerated_files</code> i din PHP-konfiguration med ett värde högre än <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache-bufferten är nästan full. För att säkerställa att alla skript kan lagras i cache, rekommenderas det att tillämpa <code>opcache.memory_consumption</code> i din PHP-konfiguration med ett värde högre än <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcachens internerade strängbuffert är nästan full. För att säkerställa att upprepade strängar effektivt kan cachelagras, rekommenderas det att använda <code>opcache.interned_strings_buffer</code> i din PHP-konfiguration med ett värde högre än <code>%s</code>.",
    "Administrator documentation" : "Administratörsdokumentation",
    "User documentation" : "Användardokumentation",
    "Invalid SMTP password." : "Ogiltigt SMTP-lösenord.",
    "Email setting test" : "E-postinställningar test",
    "Well done, %s!" : "Bra gjort, %s!",
    "If you received this email, the email configuration seems to be correct." : "Om du får detta e-postmeddelande så har du ställt in e-postinställningarna rätt.",
    "Email could not be sent. Check your mail server log" : "E-post kunde inte skickas. Titta i din e-postserverlogg",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ett problem uppstod när e-post försökte skickas. Kontrollera dina inställningar. (Fel: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Du måste ställa in din användarmailadress innan du kan skicka testmail. Gå till %s för att göra det.",
    "Users" : "Användare",
    "Invalid user" : "Ogiltig användare",
    "Invalid mail address" : "Ogiltig e-postadress",
    "Settings saved" : "Inställningar sparade",
    "Unable to change full name" : "Kunde inte ändra namn",
    "Unable to change email address" : "Kunde inte ändra e-postadress",
    "Unable to set invalid phone number" : "Kunde inte sätta ogiltigt telefonnummer",
    "Unable to set invalid website" : "Kunde inte sätta ogiltig webbplats",
    "Some account data was invalid" : "Någon kontoinformation var ogiltig",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "För att verifiera dit Twitter-konto, posta följande tweet på Twitter (Var säker att det postas utan radbrytningar):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "För att verifiera din webbplats, lagra följande innehåll i din webbrot på '.well-known/CloudIdVerificationCode.txt' (Vänligen säkerställ att hela texten ryms på en rad):",
    "%1$s changed your password on %2$s." : "%1$s ändrade ditt lösenord på %2$s",
    "Your password on %s was changed." : "Ditt lösenord på %s har ändrats.",
    "Your password on %s was reset by an administrator." : "Ditt lösenord på %s har blivit återställt av en administratör.",
    "Your password on %s was reset." : "Ditt lösenord på %s återställdes.",
    "Password for %1$s changed on %2$s" : "Lösenord för %1$s ändrades %2$s",
    "Password changed for %s" : "Lösenord ändrat för %s",
    "If you did not request this, please contact an administrator." : "Om du inte har begärt detta, vänligen kontakta en administratör.",
    "Your email address on %s was changed." : "Din e-postadress på %s har ändrats.",
    "Your email address on %s was changed by an administrator." : "Din e-postadress på %s har ändrats av en administratör.",
    "Email address for %1$s changed on %2$s" : "E-postadressen för %1$s ändrades %2$s",
    "Email address changed for %s" : "E-postadress ändrad för %s",
    "The new email address is %s" : "Nya e-postadressen är %s",
    "Your %s account was created" : "Ditt %s konto skapades",
    "Welcome aboard" : "Välkommen ombord",
    "Welcome aboard %s" : "Välkommen ombord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Välkommen till ditt %s konto, du kan lägga till, skydda och dela din data.",
    "Your username is: %s" : "Ditt användarnamn är: %s",
    "Set your password" : "Ställ in ditt lösenord",
    "Go to %s" : "Gå till %s",
    "Install Client" : "Installera Klient",
    "Logged in user must be a subadmin" : "Inloggad användare måste vara en del-administratör",
    "Settings" : "Inställningar",
    "Personal" : "Privat",
    "Administration" : "Administration",
    "Additional settings" : "Övriga inställningar",
    "Administration privileges" : "Administreringsprivilegier",
    "Groupware" : "Grupprogram",
    "Overview" : "Översikt",
    "Basic settings" : "Generella inställningar",
    "Sharing" : "Dela",
    "Availability" : "Tillgänglighet",
    "Calendar" : "Kalender",
    "Personal info" : "Personlig information",
    "Mobile & desktop" : "Mobil & skrivbord",
    "Email server" : "E-postserver",
    "Security & setup warnings" : "Säkerhet & systemvarningar",
    "Background jobs" : "Bakgrundsjobb",
    "Create" : "Skapa",
    "Change" : "Ändra",
    "Delete" : "Radera",
    "Reshare" : "Dela vidare",
    "Unlimited" : "Obegränsat",
    "Verifying" : "Verifiera",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Ett bakgrundsjobb väntar som söker efter användarimporterade SSL-certifikat. Vänligen kontrollera igen senare.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Det finns några användarimporterade SSL-certifikat närvarande som inte längre används med Nextcloud 21. De kan importeras i kommandoraden via \"occ security:certificates:import\". Deras sökvägar inuti data-mappen visas nedanför.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Ogiltiga UUID för LDAP-användare eller -grupper har hittats. Granska dina \"Åsidosätt UUID-detektering\"-inställningar i expertdelen av LDAP-konfigurationen och använd \"occ ldap:update-uuid\" för att uppdatera dem.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver MariaDB 10.2 eller högre.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL-versionen \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver MySQL 8.0 eller MariaDB 10.2 eller högre.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL-versionen \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver PostgreSQL 9.6 eller högre.",
    "Profile information" : "Profilinformation",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbild, fullständigt namn, e-post, telefonnummer, adress, webbplats, Twitter, organisation, roll, rubrik, biografi och om din profil är aktiverad",
    "Nextcloud settings" : "Nextcloud-inställningar",
    "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken grupp som har tillgång till vissa delar av administrationsinställningarna.",
    "None" : "Ingen",
    "Unable to modify setting" : "Kunde inte ändra inställning.",
    "Two-Factor Authentication" : "Tvåfaktorsautentisering",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tvåfaktorsautentisering kan påtvingas för alla användare och specifika grupper. Om de inte har en tvåfaktorsleverantör konfigurerad kommer de inte att kunna logga in i systemet.",
    "Enforce two-factor authentication" : "Påtvinga tvåfaktorsautentisering",
    "Limit to groups" : "Begränsa till grupper",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Påtvingad tvåfaktorsautentisering kan bara aktiveras för vissa grupper.",
    "Two-factor authentication is enforced for all members of the following groups." : "Tvåfaktorsautentisering är påtvingad för alla medlemmar i följande grupper.",
    "Enforced groups" : "Påtvingade grupper",
    "Two-factor authentication is not enforced for members of the following groups." : "Tvåfaktorsautentisering är inte påtvingad för medlemmar i följande grupper.",
    "Excluded groups" : "Exkluderade grupper",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "När grupper väljs/exkluderas används följande logik för att avgöra om en användare har 2FA påtvingad: Om inga grupper väljs är 2FA aktiverat för alla förutom medlemmar i exkluderade grupper. Om grupper väljs är 2FA aktiverat för alla medlemmar i dessa grupper. Om en användare är medlem i både en vald och exkluderad grupp, har den valda företräde och 2FA påtvingas.",
    "Save changes" : "Spara ändringar",
    "All" : "Alla",
    "Limit app usage to groups" : "Begränsa appanvändning till grupper",
    "No results" : "Inga resultat",
    "Update to {version}" : "Uppdatera till {version}",
    "Remove" : "Ta bort",
    "Disable" : "Inaktivera",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen lägsta Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen minimum Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Denna applikation kan inte installeras då följande beroenden inte är uppfyllda: %s",
    "View in store" : "Visa i butik",
    "Visit website" : "Besök webbplats",
    "Report a bug" : "Rapportera ett problem",
    "Admin documentation" : "Administratörsdokumentation",
    "Developer documentation" : "Utvecklardokumentation",
    "This app is supported via your current Nextcloud subscription." : "Den här appen stöds via ditt nuvarande Nextcloud-abonnemang.",
    "Supported" : "Stöds",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Utvalda appar utvecklas av och inom gemenskapen. De erbjuder central funktionalitet och är redo för produktionsanvändning.",
    "Featured" : "Utvalda",
    "Update to {update}" : "Uppdatera till {update}",
    "All apps are up-to-date." : "Alla appar är uppdaterade.",
    "Results from other categories" : "Resultat från andra kategorier",
    "No apps found for your version" : "Inga appar funna för din version",
    "Disable all" : "Inaktivera alla",
    "Enable all" : "Aktivera alla",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en uppdatering tillgänglig","%n appar har en uppdatering tillgänglig"],
    "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
    "Marked for remote wipe" : "Markerad för fjärrensning",
    "Device settings" : "Enhetsinställningar",
    "Allow filesystem access" : "Tillåt åtkomst till filsystemet",
    "Rename" : "Byt namn",
    "Revoke" : "Återkalla",
    "Wipe device" : "Rensa enhet",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Återkallning kan förhindra att enheten rensas om inte rensningen redan har startat.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome för Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS app",
    "{productName} Android app" : "{productName} Android app",
    "{productName} Talk for iOS" : "{productName} Talk för iOS",
    "{productName} Talk for Android" : "{productName} Talk för Android",
    "Sync client - {os}" : "Synkroniseringsklient - {os}",
    "This session" : "Denna session ",
    "Device" : "Enhet",
    "Last activity" : "Senaste aktivitet",
    "Devices & sessions" : "Enheter & sessioner",
    "Web, desktop and mobile clients currently logged in to your account." : "Webb-, skrivbords- och mobila klienter som är inloggade på ditt konto just nu.",
    "Do you really want to wipe your data from this device?" : "Vill du verkligen radera din data från den här enheten?",
    "Confirm wipe" : "Bekräfta radering",
    "Error while creating device token" : "Fel vid skapande av enhetstoken",
    "Error while updating device token scope" : "Fel vid uppdatering av enhetstokens omfång",
    "Error while updating device token name" : "Fel vid uppdatering av enhetstokens namn",
    "Error while deleting the token" : "Fel vid borttagning av token",
    "Error while wiping the device with the token" : "Fel uppstod vid rensning av enheten",
    "App name" : "Appnamn",
    "Create new app password" : "Skapa nytt applösenord",
    "Use the credentials below to configure your app or device." : "Använd följande autentiseringsuppgifter för att konfigurera din app eller enhet",
    "For security reasons this password will only be shown once." : "Av säkerhetsskäl kommer lösenordet endast att visas en gång",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Done" : "Färdig",
    "Show QR code for mobile apps" : "Visa QR-kod för mobila appar",
    "Copied!" : "Kopierad!",
    "Copy" : "Kopiera",
    "Could not copy app password. Please copy it manually." : "Det gick inte att kopiera applösenordet. Kopiera det manuellt.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "För att servern ska fungera korrekt är det viktigt att konfigurera bakgrundsjobb korrekt. Cron är den rekommenderade inställningen. Se dokumentationen för mer information.",
    "Last job execution ran {time}. Something seems wrong." : "Senaste jobbexekveringen kördes {time}. Något verkar vara fel.",
    "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
    "Background job did not run yet!" : "Bakgrundsjobb har inte kört ännu!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Utför en uppgift med varje sidladdning. Användningsfall: instans med en användare.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php är registrerad på en webcron-tjänst för att anropa cron.php var 5:e minut över HTTP. Användningsfall: Mycket liten instans (1–5 användare beroende på användning).",
    "Cron (Recommended)" : "Cron (Rekommenderad)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "För att köra detta behöver du PHP POSIX-tillägget. Se {linkstart}PHP dokumentation{linkend} för mer detaljer.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Använd systemets cron-tjänst för att anropa filen cron.php var 5:e minut. Rekommenderas för alla fall.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php måste köras av systemanvändaren \"{user}\".",
    "Unable to update background job mode" : "Det gick inte att uppdatera bakgrundsjobbläget",
    "Profile" : "Profil",
    "Enable or disable profile by default for new users." : "Aktivera eller inaktivera profil som standard för nya användare.",
    "Enable" : "Aktivera",
    "Unable to update profile default setting" : "Det gick inte att uppdatera profilens standardinställning",
    "Server-side encryption" : "Serverkryptering",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering från servern möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
    "Enable server-side encryption" : "Aktivera kryptering på server.",
    "Please read carefully before activating server-side encryption:" : "Läs noga innan du aktiverar kryptering på serversidan:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "När kryptering är aktiverat, så kommer alla filer som laddas upp till servern från den tidpunkt och framåt bli krypterad på servern. Det kommer bara vara möjligt att inaktivera kryptering vid ett senare tillfälle om krypteringsmodulen stödjer den funktionen och alla förvillkor (exempelvis använder återställningsnyckel) är mötta.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Enbart kryptering garanterar inte säkerhet i systemet. Se dokumentationen för ytterligare information om hur krypteringsappen fungerar, och de supporterade användarfallen.",
    "Be aware that encryption always increases the file size." : "OBS! Observera att kryptering alltid ökar filstorleken",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det är alltid en god ide att skapa regelbundna säkerhetskopior av din data, om kryptering används var säker på att även krypteringsnycklarna säkerhetskopieras tillsammans med din data.",
    "This is the final warning: Do you really want to enable encryption?" : "Detta är en slutgiltig varning: Vill du verkligen aktivera kryptering?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul inläst, aktivera krypteringsmodulen i applikationsmenyn.",
    "Select default encryption module:" : "Välj krypteringsmodul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Du måste migrera dina krypteringsnycklar från den gamla krypteringen (ownCloud <= 8.0) till den nya. Aktivera \"Standard krypteringsmodule\" och kör {command}",
    "Unable to update server side encryption config" : "Kunde inte uppdatera serversidans krypteringskonfiguration",
    "Rename group" : "Byt namn på grupp",
    "Remove group" : "Ta bort grupp",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Du håller på att ta bort gruppen {group}. Användarna kommer INTE att raderas.",
    "Please confirm the group removal " : "Bekräfta borttagning av gruppen",
    "Current password" : "Nuvarande lösenord",
    "New password" : "Nytt lösenord",
    "Change password" : "Ändra lösenord",
    "Your profile information" : "Din profilinformation",
    "Your profile picture" : "Din profilbild",
    "Upload profile picture" : "Ladda upp profilbild",
    "Choose profile picture from Files" : "Välj profilbild från filer",
    "Remove profile picture" : "Ta bort profilbild",
    "Picture provided by original account" : "Bild gjordes tillgänglig av orginalkonto",
    "Cancel" : "Avbryt",
    "Set as profile picture" : "Ställ in som profilbild",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Observera att det kan ta upp till 24 timmar för din profilbild att uppdateras överallt.",
    "Choose your profile picture" : "Välj din profilbild",
    "Please select a valid png or jpg file" : "Välj en giltig png- eller jpg-fil",
    "Error setting profile picture" : "Fel vid inställning av profilbild",
    "Error cropping profile picture" : "Det gick inte att beskära profilbilden",
    "Error saving profile picture" : "Det gick inte att spara profilbilden",
    "Error removing profile picture" : "Det gick inte att ta bort profilbilden",
    "Your biography" : "Din biografi",
    "Details" : "Detaljer",
    "You are a member of the following groups:" : "Du är medlem i följande grupper:",
    "You are using <strong>{usage}</strong>" : "Du använder <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du använder <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Ditt fullständiga namn",
    "Email options" : "E-postinställningar",
    "Primary email for password reset and notifications" : "Primär e-postadress för notifikationer och återställning av lösenord",
    "Remove primary email" : "Ta bort primär e-postadress",
    "Delete email" : "Ta bort e-post",
    "Unset as primary email" : "Ta bort som primär e-post",
    "This address is not confirmed" : "Denna adress är inte verifierad",
    "Set as primary email" : "Välj som primär e-post",
    "Your email address" : "Din e-postadress",
    "Additional email address {index}" : "Ytterligare e-postadress {index}",
    "Unable to delete primary email address" : "Kunde inte ta bort primär e-postadress",
    "Unable to update primary email address" : "Kunde inte uppdatera primär e-postadress",
    "Unable to add additional email address" : "Kunde inte lägga till ytterligare e-postadress",
    "Unable to update additional email address" : "Kunde inte uppdatera ytterligare e-postadress",
    "Unable to delete additional email address" : "Kunde inte ta bort ytterligare e-postadress",
    "No email address set" : "Ingen e-postadress angiven",
    "Additional emails" : "Ytterligare e-postadresser",
    "Your handle" : "Ditt kontonamn",
    "Your headline" : "Din rubrik",
    "Language" : "Språk",
    "Help translate" : "Hjälp till med översättningarna",
    "Unable to update language" : "Kunde inte uppdatera språk",
    "No language set" : "Inget språk angivet",
    "Locale" : "Plats",
    "Week starts on {firstDayOfWeek}" : "Veckan börjar med {firstDayOfWeek}",
    "Unable to update locale" : "Det gick inte att uppdatera språk",
    "No locale set" : "Inget språk angivet",
    "Your location" : "Din plats",
    "Your organisation" : "Din organisation",
    "Your phone number" : "Ditt telefonnummer",
    "Edit your Profile visibility" : "Ändra synligheten för din profil",
    "Enable Profile" : "Aktivera profil",
    "Unable to update profile enabled state" : "Kunde inte uppdatera profilaktivering",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Den mer restriktiva inställningen av antingen synlighet eller omfattning respekteras på din profil. Till exempel, om synlighet är inställd på \"Visa för alla\" och omfattningen är inställd på \"Privat\", respekteras \"Privat\".",
    "Unable to update visibility of {displayId}" : "Kunde inte uppdatera synlighet för {displayId}",
    "Your role" : "Din roll",
    "Your Twitter handle" : "Ditt Twitterkonto",
    "Your website" : "Din webbsida",
    "No {property} set" : "Ingen {property} inställd",
    "Unable to update {property}" : "Det gick inte att uppdatera {property}",
    "Change scope level of {property}, current scope is {scope}" : "Ändra omfattningsnivå för {property}, nuvarande omfattning är {scope}",
    "Unable to update federation scope of the primary {property}" : "Det gick inte att uppdatera federationsomfånget för den primära {property}",
    "Unable to update federation scope of additional {property}" : "Det gick inte att uppdatera federationens omfattning för ytterligare {property}",
    "Add additional email" : "Lägg till ytterligare e-post",
    "Add" : "Lägg till",
    "You do not have permissions to see the details of this user" : "Du har inte behörighet att se detaljerna för den här användaren",
    "Add new password" : "Lägg till nytt lösenord",
    "Add new email address" : "Lägg till ny e-postadress",
    "Add user to group" : "Lägg till användare i grupp",
    "Set user as admin for" : "Gör användare till admin för",
    "Select user quota" : "Välj användarens quota",
    "Delete user" : "Ta bort användare",
    "Wipe all devices" : "Rensa alla enheter",
    "Disable user" : "Stäng av användare",
    "Enable user" : "Aktivera användare",
    "Resend welcome email" : "Skicka om välkomstmeddelande via e-post",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Om användaren förlorar sin enhet eller lämnar organisationen, kan all Nextcloud-data fjärrensas från alla enheter associerade med {userid}. Fungerar bara om enheterna är anslutna till internet.",
    "Remote wipe of devices" : "Fjärrensning av enheter",
    "Wipe {userid}'s devices" : "Rensa enheter för {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Fullständig radering av konto för {userid} inklusive alla personliga filer, appdata etc.",
    "Account deletion" : "Radering av konto",
    "Delete {userid}'s account" : "Ta bort konto för {userid}",
    "Welcome mail sent!" : "Välkomstmeddelande skickat via e-post!",
    "Edit User" : "Redigera användare",
    "Toggle user actions menu" : "Växla menyn med användaråtgärder",
    "{size} used" : "{size} använt",
    "New user" : "Ny användare",
    "Will be autogenerated" : "Kommer att autogenereras",
    "Display name" : "Visningsnamn",
    "Email" : "E-post",
    "Default language" : "Standardspråk",
    "Add a new user" : "Lägg till ny användare",
    "Group admin for" : "Gruppadministratör för",
    "Quota" : "Lagringsutrymme",
    "User backend" : "Användarbackend",
    "Storage location" : "Lagringsplats",
    "Last login" : "Senaste inloggning",
    "No users in here" : "Inga användare här",
    "Default quota" : "Standard kvot",
    "Common languages" : "Vanliga språk",
    "Other languages" : "Andra språk",
    "Password change is disabled because the master key is disabled" : "Lösenordsbyte är inaktiverat eftersom huvudnyckeln är inaktiverad",
    "Passwordless authentication requires a secure connection." : "Lösenordsfri autentisering kräver en säker anslutning.",
    "Add WebAuthn device" : "Lägg till WebAuthn-enhet",
    "Please authorize your WebAuthn device." : "Godkänn din WebAuthn-enhet.",
    "Name your device" : "Namnge din enhet",
    "Adding your device …" : "Lägger till din enhet ....",
    "Server error while trying to add WebAuthn device" : "Serverfel när du försökte lägga till en WebAuthn-enhet",
    "Server error while trying to complete WebAuthn device registration" : "Serverfel när du försökte slutföra registreringen av en WebAuthn-enhet",
    "Unnamed device" : "Namnlös enhet",
    "Passwordless Authentication" : "Lösenordsfri autentisering",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Ställ in ditt konto för lösenordsfri autentisering som följer FIDO2-standarden.",
    "No devices configured." : "Inga enheter konfigurerade.",
    "The following devices are configured for your account:" : "Följande enheter är konfigurerade för ditt konto:",
    "Your browser does not support WebAuthn." : "Din webbläsare stödjer inte WebAuthn.",
    "Your apps" : "Dina appar",
    "{license}-licensed" : "{license}-licensierad",
    "Changelog" : "Ändringslogg",
    "by {author}\n{license}" : "av {author}\n{license}",
    "Enter group name" : "Ange gruppnamn",
    "Add group" : "Lägg till grupp",
    "Active users" : "Aktiva användare",
    "Admins" : "Administratörer",
    "Disabled users" : "Inaktiva användare",
    "Default quota:" : "Standardkvot:",
    "Select default quota" : "Välj standard kvot",
    "Show Languages" : "Visa språk",
    "Show last login" : "Visa senaste inloggning",
    "Show user backend" : "Visa användar-backend",
    "Show storage path" : "Visa lagringsväg",
    "Send email to new user" : "Skicka e-post till ny användare",
    "Not saved" : "Inte sparad",
    "Sending…" : "Skickar...",
    "Email sent" : "E-post skickad",
    "Location" : "Plats",
    "Profile picture" : "Profilbild",
    "About" : "Om",
    "Full name" : "Namn",
    "Additional email" : "Ytterligare e-postadress",
    "Headline" : "Rubrik",
    "Organisation" : "Organisation",
    "Phone number" : "Telefonnummer",
    "Role" : "Roll",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "Fediverse (t.ex. Mastodon)",
    "Website" : "Webbplats",
    "Profile visibility" : "Profilsynlighet",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Inte tillgänglig då denna inställning krävs för essentiell funktionalitet såsom fildelning och kalenderinbjudningar",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Ej tillgängligt eftersom federation har inaktiverats för ditt konto, kontakta din systemadministratör om du har några frågor",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Inte tillgänglig då publicering av användarspecifik data till lookup-servern inte är tillåten, kontakta din systemadministratör ifall du har frågor",
    "Active apps" : "Aktiva appar",
    "Disabled apps" : "Inaktiverade appar",
    "Updates" : "Uppdateringar",
    "App bundles" : "App-paket",
    "Featured apps" : "Utvalda appar",
    "Show to everyone" : "Visa för alla",
    "Show to logged in users only" : "Visa endast för inloggade användare",
    "Hide" : "Dölj",
    "Download and enable" : "Hämta och aktivera",
    "Enable untested app" : "Aktivera otestad app",
    "The app will be downloaded from the App Store" : "Appen kommer hämtas från appbutiken",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
    "Never" : "Aldrig",
    "An error occurred during the request. Unable to proceed." : "Ett fel uppstod under begäran. Det gick inte att fortsätta.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen har aktiverats men måste uppdateras. Du kommer att omdirigeras till uppdateringssidan om 5 sekunder.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det kom för många förfrågningar från ditt nätverk. Försök senare eller kontakta din administratör om detta är ett fel.",
    "Documentation" : "Dokumentation",
    "Forum" : "Forum",
    "Login" : "Logga in",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "Öppna dokumentation",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det är viktigt att konfigurera den här servern för att kunna skicka e-post, till exempel för återställning av lösenord och aviseringar.",
    "Send mode" : "Sändningsläge",
    "Encryption" : "Kryptering",
    "Sendmail mode" : "Sendmail-läge",
    "From address" : "Från adress",
    "Server address" : "Serveradress",
    "Port" : "Port",
    "Authentication method" : "Autentiseringsmetod",
    "Only applies when authentication is required" : "Gäller endast när autentisering krävs",
    "Authentication required" : "Autentisering krävs",
    "Credentials" : "Inloggningsuppgifter",
    "SMTP Username" : "SMTP-användarnamn",
    "SMTP Password" : "SMTP-lösenord",
    "Save" : "Spara",
    "Test and verify email settings" : "Testa och verifiera e-postinställningar",
    "Send email" : "Skicka e-post",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda av din instans att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
    "All checks passed." : "Alla kontroller lyckades!",
    "There are some errors regarding your setup." : "Det finns några fel angående din inställning.",
    "There are some warnings regarding your setup." : "Det finns några varningar angående din inställning.",
    "Checking for system and security issues." : "Kontrollerar system och säkerhetsproblem.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Vänligen dubbelkolla <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installationsguiderna ↗</a>, och leta efter eventuella fel eller varningar i <a href=\"%2$s\">loggen</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrollera säkerheten för ditt Nextcloud över <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår säkerhetsgenomsökning ↗</a>.",
    "Version" : "Version",
    "You need to enable the File sharing App." : "Du måste aktivera fildelnings-appen.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du fininställa delningsbeteendet. Vänligen se dokumentationen för mer information.",
    "Allow apps to use the Share API" : "Tillåt applikationer att använda API för delning",
    "Set default expiration date for shares" : "Ställ in standardutgångsdatum för delningar",
    "Expire after" : "Utgår efter",
    "day(s)" : "dag(ar)",
    "Enforce expiration date" : "Tillämpa förfallodatum",
    "Set default expiration date for shares to other servers" : "Ställ in standardutgångsdatum för delningar",
    "Allow users to share via link and emails" : "Tillåt användare att dela via länk och e-post",
    "Allow public uploads" : "Tillåt offentlig uppladdning",
    "Always ask for a password" : "Fråga alltid efter lösenord",
    "Enforce password protection" : "Tillämpa lösenordskydd",
    "Exclude groups from password requirements:" : "Exkludera grupper från lösenordskrav: ",
    "Set default expiration date" : "Ställ in standardutgångsdatum",
    "Exclude groups from creating link shares:" : "Exkludera grupper från att skapa länkdelningar:",
    "Allow resharing" : "Tillåt vidaredelning",
    "Allow sharing with groups" : "Tillåt delning med grupper",
    "Restrict users to only share with users in their groups" : "Begränsa användare till att enbart kunna dela med användare i deras grupper",
    "Exclude groups from sharing" : "Exkludera grupp från att dela",
    "These groups will still be able to receive shares, but not to initiate them." : "Dessa grupper kommer fortfarande kunna ta emot delningar, men inte skapa delningar.",
    "Allow username autocompletion in share dialog" : "Tillåt autokomplettering av användarnamn i delningsdialogen",
    "Allow username autocompletion to users within the same groups" : "Tillåt autokomplettering av användarnamn till användare inom samma grupper",
    "Allow username autocompletion to users based on phone number integration" : "Tillåt autokomplettering av användarnamn till användare baserad på telefonnummerintegration",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Om komplettering för \"samma grupp\" och \"telefonnummerintegration\" är aktiverade räcker det med en matchning i en av dem för att visa användaren.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt autokomplettering när du anger hela namnet eller e-postadressen (ignorera saknad telefonboksmatchning och att vara i samma grupp)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Visa friskrivningstext på offentliga uppladdningssidan (visas endast när fil-listan är gömd)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Denna text kommer att visa på den offentliga uppladdnings-sidan när fil-listan är gömd.",
    "Default share permissions" : "Standardrättigheter för delning",
    "Reasons to use Nextcloud in your organization" : "Anledningar att använda Nextcloud i din organisation",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utvecklat av {communityopen}Nextcloud-gemenskapen{linkclose}, {githubopen}källkoden{linkclose}  är licensierad enligt {licenseopen}AGPL-standard{linkclose}.",
    "Like our Facebook page" : "Gilla vår Facebook-sida",
    "Follow us on Twitter" : "Följ oss på Twitter",
    "Follow us on Mastodon" : "Följ oss på Mastodon",
    "Check out our blog" : "Kolla in vår blogg",
    "Subscribe to our newsletter" : "Prenumerera på vårt nyhetsbrev",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
    "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor förutom ditt lösenord för att öka säkerheten för ditt konto.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
    "An error occurred while changing your language. Please reload the page and try again." : "Ett fel inträffade när ditt språk ändrades. Vänligen uppdatera sidan och försök igen.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Ett fel inträffade när din språk ändrades. Vänligen uppdatera sidan och försök igen.",
    "Select a profile picture" : "Välj en profilbild",
    "Week starts on {fdow}" : "Veckan börjar med {fdow}",
    "You created app password \"{token}\"" : "Du skapade applösenord \"{token}\"",
    "An administrator created app password \"{token}\"" : "En administratör skapade applösenord \"{token}\"",
    "Couldn't remove app." : "Kunde inte ta bort applikationen.",
    "Couldn't update app." : "Kunde inte uppdatera appen.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Backend stödjer inte att lösenord ändras men användarens krypteringsnyckel uppdaterades.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Kunde inte bestämma om TLS-versionen av cURL är för gammal eller inte för ett fel uppstod under HTTPS-förfrågan mot https://nextcloud.com. Vänligen kontrollera nextcloud loggfilen för fler detaljer.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Det maximala antalet OPcache-nycklar har nästan överskridits. För att säkerställa att alla skript kan hållas i cache, rekommenderas det att tillämpa <code>opcache.max_accelerated_files</code> i din PHP-konfiguration med ett värde högre än <code>%s</code>.",
    "Admin privileges" : "Adminprivilegier",
    "Unable to update biography" : "Kunde inte uppdatera biografi",
    "Unable to update full name" : "Kunde inte uppdatera fullständigt namn",
    "No full name set" : "Inget fullständigt namn angivet",
    "Unable to update headline" : "Kunde inte uppdatera rubrik",
    "Unable to update organisation" : "Kunde inte uppdatera organisation",
    "Unable to update role" : "Kunde inte uppdatera roll",
    "Change scope level of {accountProperty}" : "Ändra omfattningsnivå för {accountProperty}",
    "Unable to update federation scope of the primary {accountProperty}" : "Det gick inte att uppdatera federationsomfånget för primära {accountProperty}",
    "Unable to update federation scope of additional {accountProperty}" : "Det gick inte att uppdatera federationens omfattning för ytterligare {accountProperty}",
    "Migration in progress. Please wait until the migration is finished" : "Migration pågår. Vänta tills migrationen är klar",
    "Migration started …" : "Migrering påbörjad ...",
    "Address" : "Ort/Stad",
    "Avatar" : "Avatar",
    "An error occured during the request. Unable to proceed." : "Ett fel uppstod under förfrågan. Kan inte fortsätta.",
    "Plain" : "Enkel",
    "NT LAN Manager" : "NT LAN Manager",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "Läs noga innan du aktiverar kryptering på serversidan: ",
    "Enable encryption" : "Aktivera kryptering",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya. Aktivera \"Standard krypteringsmodul\" och kör 'occ encryption:migrate'.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya.",
    "Start migration" : "Starta migrering",
    "Last job execution ran %s. Something seems wrong." : "Sista jobbexekveringen körde %s. Något verkar vara fel.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Vissa jobb har inte utförts sedan %s. Överväg att justera tid för exekvering.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Vissa jobb utfördes inte sedan %s. Överväg att byta till system cron.",
    "Last job ran %s." : "Senaste jobbet kördes %s.",
    "Background job didn’t run yet!" : "Bakgrundsjobb har inte kört ännu!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "För att servern ska fungera korrekt är det viktigt att konfigurera bakgrundsjobb korrekt. \"Cron\" är den rekommenderade inställningen. Se dokumentationen för mer information.",
    "Pick background job setting" : "Välj inställning för bakgrundsjobb",
    "Recommended" : "Rekomenderad",
    "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php behöver exekveras av systemanvändaren \"%s\".",
    "Change privacy level of profile picture" : "Ändra hemlighetsnivå för profilbild",
    "Upload new" : "Ladda upp ny",
    "Select from Files" : "Välj från Filer",
    "Remove image" : "Ta bort bild",
    "png or jpg, max. 20 MB" : "png eller jpg, max 20 MB",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Observera att det kan ta upp till 24 timmar för avataren att uppdateras överallt.",
    "Choose as profile picture" : "Välj som profilbild",
    "You are using <strong>%s</strong>" : "Du använder <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Du använder <strong>%1$s</strong> av <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of phone number" : "Ända hemlighetsnivå för telefonnummer",
    "Change privacy level of address" : "Ända hemlighetsnivå för adress",
    "Your postal address" : "Ort/Stad",
    "Change privacy level of website" : "Ända hemlighetsnivå för hemsida",
    "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta upp till 24 timmar innan kontot visas som verifierat.",
    "Link https://…" : "Länk https://...",
    "Change privacy level of Twitter profile" : "Ända hemlighetsnivå för Twitterprofil",
    "Twitter handle @…" : "Twitter handle @…",
    "Choose profile picture from files" : "Välj profilbild från filer"
},
"nplurals=2; plural=(n != 1);");
